@@ -5,17 +5,19 @@ from fbp.builder import *
 # ---------------------------
 #  BuildPy
 # ---------------------------
-def main():
+def main() -> int:
   argv = sys.argv
 
   try:
     builder = Builder()
 
-    builder.run(argv)
+    return builder.run(argv)
   except FileNotFoundError as e:
     print(f'cannot open file "{e.filename}"')
-  #except Exception as e:
-  #  print(f'unhandled exception have been occurred:\n\nmsg: {e.args}')
+  except Exception as e:
+    print(f'unhandled exception have been occurred:\n\nmsg: {e.args}')
+  
+  return -1
 
 # ------
 
